# App Settings

![Tests](https://github.com/wheelercj/app_settings/actions/workflows/tests.yaml/badge.svg)

A dictionary-like Settings class for managing an application's settings.

Install with `pip install app-settings-dict`.
Import with `import app_settings`.

See [the test file](https://github.com/wheelercj/app_settings/blob/master/tests/test_app_settings.py) for example uses.
